/**
 *******************************************************************************
 *
 * @file        MG32x02z_OPA_Init.c
 *
 * @brief       The OPA initial code C file 
 *
 * @par         Project
 *              MG32x02z
 * @version     V1.02
 * @date        2024/04/26
 * @author      Megawin Software Center
 * @copyright   Copyright (c) 2020 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 *******************************************************************************
 * @par         Disclaimer
 * The Demo software is provided "AS IS" without any warranty, either
 * expressed or implied, including, but not limited to, the implied warranties
 * of merchantability and fitness for a particular purpose. The author will
 * not be liable for any special, incidental, consequential or indirect
 * damages due to loss of data or any other reason.
 * These statements agree with the world wide and local dictated laws about
 * authorship and violence against these laws.
 *******************************************************************************
 *******************************************************************************
 */


/* Includes ------------------------------------------------------------------*/
#include "MG32x02z.h"
#include "MG32x02z_OPA.h"
#include "MG32x02z_OPA_Init.h"

/* Wizard menu ---------------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
// (Middleware level)
#if defined(IRQHandler_Middleware_Level_)       
    #if defined (__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050) /* ARM Compiler V6 */
        #pragma clang diagnostic push
        #pragma clang diagnostic ignored "-Wmissing-variable-declarations"
            OPA_HandleTypeDef        mOPA;
        #pragma clang diagnostic pop
    // ------------------------------------------------------------------------
    #else
        OPA_HandleTypeDef        mOPA;
    #endif
    // ------------------------------------------------------------------------
#endif


/* Private function prototypes -----------------------------------------------*/
/* Exported variables --------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/
/* External vairables --------------------------------------------------------*/


/**
 *******************************************************************************
 * @brief  	    Initialized Analog Comparator module.
 * @param[in]   None
 * @return      None
 *******************************************************************************
 */
void OPA_ACx_Init(void)
{
    
    #if CONF_OPA_MODE != 0
        /* OPA register initial */
        OPA->INT.W = CONF_OPA_INT;
        OPA->CR0.W  = CONF_OPA_CR0;
        // --------------------------------------------------------------------
        // Config mOPA structure within Middleware level
        // --------------------------------------------------------------------
        #if defined(IRQHandler_Middleware_Level_)       
            mOPA.Instance                   = OPAAC0;
            
            #if CONF_OPA_MODE_SEL == 0x00000000
                mOPA.Init.InvertingInput    = CONF_OPA_OPAPMUX;
                mOPA.Init.NonInvertingInput = CONF_OPA_OPANMUX;
                mOPA.Init.FunctionMode      = OPA_MODE;
                mOPA.Init.PowerMode         = CONF_OPA_OPALPEN;
            #else
                mOPA.Init.InvertingInput    = CONF_OPA_CMPPMUX;
                mOPA.Init.NonInvertingInput = CONF_OPA_CMPNMUX;
                mOPA.Init.FunctionMode      = OPA_CMP_MODE;
                mOPA.Init.PowerMode         = CONF_OPA_CMPLPEN;
            #endif
            
            mOPA.Init.ComparatorPol         = CONF_OPA_CR0_INV;
            mOPA.Init.TriggerMode           = (CONF_OPA_INT_OP0_RIE | CONF_OPA_INT_OP0_FIE);
            mOPA.Init.OutputSync            = CONF_OPA_CR0_FSEL;
            mOPA.Init.SyncFilterDIV         = CONF_OPA_CR0_FDIV;
            // MID_OPA_Init(&mADC);
        #endif
    #endif

}


