




 /**
 ******************************************************************************
 *
 * @file        MCU.c
 * @brief       The mcu Code's c file.
 *
 * @par         Project
 *              MG32x02z
 * @version     V1.02
 * @date        2023/05/17
 * @author      Megawin Software Center
 * @copyright   Copyright (c) 2017 MegaWin Technology Co., Ltd.
 *              All rights reserved.
 * 
 ******************************************************************************* 
 * @par Disclaimer
 * The Demo software is provided "AS IS" without any warranty, either
 * expressed or implied, including, but not limited to, the implied warranties
 * of merchantability and fitness for a particular purpose. The author will
 * not be liable for any special, incidental, consequential or indirect
 * damages due to loss of data or any other reason.
 * These statements agree with the world wide and local dictated laws about
 * authorship and violence against these laws.
 *******************************************************************************
 *******************************************************************************
 */


/* Includes ------------------------------------------------------------------*/
#include "MG32x02z.h"
#include "MG32x02z_USB.h"
#include "MG32x02z_USB_DRV.h"
#include "MG32x02z_PW_DRV.h"
#include "MG32x02z_TM_DRV.h"
#include "MG32x02z_USBD_EasyPODMini.h"
#include "MG32x02z_USBD_Keyboard_API.h"
#include "MG32x02z_CFG.h"
#include "MG32x02z_RGB_API.h"

/* Wizard menu ---------------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
void TM0x_IRQHandler(void);
void MCU_Init(void);

/* Exported variables --------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/
extern void ChipInit(void);

/* External variables --------------------------------------------------------*/

/**
 *******************************************************************************
 * @brief	    TM0x IRQ handler function
 * @details     
 * @return      
 * @exception   No
 * @note        No
 *******************************************************************************
 */
void TM0x_IRQHandler(void)
{
    uint32_t TM00_FLAG;
    
    TM00_FLAG = TM_GetAllFlagStatus( TM00);
    
    if( TM00_FLAG & TMx_TOF)
    {
        KB.Scan_Flag_Start = 1;
        
        TM_ClearFlag( TM00 , TMx_TOF);
    }
}
/**
 *******************************************************************************
 * @brief	    MCU initial.
 * @details     
 * @return      
 * @exception   No
 * @note        No
 *******************************************************************************
 */
void MCU_Init(void)
{
    //========================================
    //CSC & GPIO Initial
    ChipInit();
    
    //=======================================
    //Keyboard Initial
    
    //---------------------------------------
    //USB Power Control Related
    UnProtectModuleReg(PWprotect);
    
    PW_PeriphSLEEPModeContinuous_Config(PW_SLPPO_USB,ENABLE);
    PW_PeriphSTOPModeWakeUp_Config( PW_WKSTP_USB , ENABLE);
    ProtectModuleReg(PWprotect);
    
    //---------------------------------------
    //Keyboard Initial
    API_KB_Init();
    
    //----------------------------------------
    //USB Initial
    Init();

    //=======================================
    //LED Initial
    #if MG32x02z_USBD_KEYBOARD_RGB_EN != API_RGB_DISABLE
        API_RGB_Init();
    #endif
    
}








